#  Copyright (c) 2022 bastien.saltel
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from django.apps import AppConfig


class TimeConfig(AppConfig):
    """
   classdocs
   """

    name = "galaxy.www.django.time"
    verbose_name = "Time Static Data"

    def ready(self):
        pass



#  Copyright (c) 2022 bastien.saltel
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from galaxy.data.db.orm.django.iso import Country,                          \
                                          Continent,                        \
                                          CountryContinent,                 \
                                          CurrencyType,                     \
                                          Currency,                         \
                                          CountryCurrency,                  \
                                          PhonePrefix,                      \
                                          Language,                         \
                                          MarketExchange,                   \
                                          InstrumentCategory,               \
                                          InstrumentGroup,                  \
                                          VotingRight,                      \
                                          InstrumentOwnership,              \
                                          PaymentStatus,                    \
                                          IncomeType,                       \
                                          RedemptionConversionType,         \
                                          DistributionType,                 \
                                          DistributionPolicy,               \
                                          ClosedOpenEnd,                    \
                                          GuaranteeType,                    \
                                          InterestType,                     \
                                          RedemptionReimbursementType,      \
                                          SecurityType,                     \
                                          OptionType,                       \
                                          WarrantType,                      \
                                          Termination,                      \
                                          DeliveryType,                     \
                                          WeightingType,                    \
                                          IndexReturnType,                  \
                                          BasketComposition,                \
                                          TimeFrequency,                    \
                                          EquityType

